----------------------------------------------------------------
Comands for processing the problem
----------------------------------------------------------------

gmsh case -3 2>> sv.log
getdp case -msh case.msh -solve MagSta_phi 2>> sv.log
getdp case -pos phi
getdp case -pos grid

----------------------------------------------------------------
Commands for gnuplot
----------------------------------------------------------------

# Bx in plane -------------------------------------------------

set title "Bx for plane xy - other side of anomaly"
set xlabel "x (mm)"
set ylabel "y (mm)"
set zlabel "Bx (Tesla)"
set xr [*:*]
set yr [*:*]
set zr [*:*]
sp "bxyz0040e.txt" u ($3*1000):($4*1000):(-$9) title "" w lines

set xr [-60:60]
set yr [-60:60]
replot
set view 90,90;replot
set view 90,0;replot

set title "Bx for plane xy - same side of anomaly"
set xlabel "x (mm)"
set ylabel "y (mm)"
set zlabel "Bx (Tesla)"
set xr [*:*]
set yr [*:*]
set zr [*:*]
sp "bxyz0040i.txt" u ($3*1000):($4*1000):(-$9) title "" w lines

# Bx in X line -------------------------------------------------

set title "Bx in the X axis 4 mm for the other side of anomaly"
set xlabel "x (mm)"
set ylabel "Bx (Tesla)"
set xr [0:80]
set yr [*:*]
set grid
#set ytics 0.0002
p "bxy0z0040e.txt"  u ($3*1000):(-$9) title "4 mm"
p "bxy0z0040e.txt"  u ($3*1000):(-$9) title "4 mm" w lines

set title "Bx in the X axis 4 mm for the same side of anomaly"
set xlabel "x (mm)"
set ylabel "Bx (Tesla)"
set xr [0:80]
set yr [*:*]
set grid
#set ytics 0.0002
p "bxy0z0040i.txt"  u ($3*1000):(-$9) title "4 mm"
p "bxy0z0040i.txt"  u ($3*1000):(-$9) title "4 mm" w lines

# Bx in Y line -------------------------------------------------

set title "Bx in the Y axis 4 mm for the other side of anomaly"
set xlabel "x (mm)"
set ylabel "Bx (Tesla)"
set xr [*:*]
set yr [*:*]
set xtics 5
p "bx0yz0040e.txt"  u ($4*1000):(-$9) title "4 mm"
p "bx0yz0040e.txt"  u ($4*1000):(-$9) title "4 mm" w lines

set title "Bx in the Y axis 4 mm for the same side of anomaly"
set xlabel "x (mm)"
set ylabel "Bx (Tesla)"
set xr [*:*]
set yr [*:*]
set xtics 5
p "bx0yz0040i.txt"  u ($4*1000):(-$9) title "4 mm"
p "bx0yz0040i.txt"  u ($4*1000):(-$9) title "4 mm" w lines

# mu(H) curve for steel plate --------------------------------

# Note that muh-puc-adj.txt (used in curve fitting) is the same
# as muh-puc.txt (used in comparision) with the first points
# Fitting is restricted in the region of interest
# Relative errors stay below +-7% for H > 70000 A/m,
# below +-10% for 210 A/m < H < 70000 A/m and
# around 20% for H ~= 210 A/m

set title "Steel plate mu(H) curve "
as=1; bs=1;
mu(x)=1./(as + bs * x )
fit [500:*] mu(x) "muh-puc.txt" u 1:2 via as,bs
set logscale
set xlabel "H (A/m))"
set ylabel "mu(H)"
p "muh-puc.txt" u 1:2 title "Experimental points", \
mu(x) title "Adjusted curve"

# fitted values
as = 471.384;
bs = 0.452111;
mu(x)=1./(as + bs * x )
# function to be used with getdp (in this case):
# mu[Steel] = 1./(as + bs * Norm[$1])

set title "Relative error for steel plate mu(H) curve"
set logscale
set xlabel "H (A/m))"
set ylabel "% error"
set grid
p "muh-puc.txt" u 1:(abs(($2-mu($1))/$2*100)) title ""

#-----------------------------------------------------------------
set title "Steel plate mu(H) curve "
as=1; bs=1; cs=1;
mu(x)=1./(as + bs * x ** cs)
fit [500:*] mu(x) "muh-puc.txt" u 1:2 via as,bs,cs
set logscale
set xlabel "H (A/m))"
set ylabel "mu(H)"
p "muh-puc.txt" u 1:2 title "Experimental points", \
mu(x) title "Adjusted curve"

# fitted values
as              = 196.57           +/- 5.437        (2.766%)
bs              = 0.74843          +/- 0.02446      (3.269%)
cs              = 0.963545         +/- 0.003624     (0.3761%)
mu(x)=1./(as + bs * x ** cs)
# function to be used with getdp (in this case):
# mu[Steel] = 1./(as + bs * Norm[$1] ^ cs)

set title "Relative error for steel plate mu(H) curve"
set logscale
set xlabel "H (A/m))"
set ylabel "% error"
set grid
p "muh-puc.txt" u 1:(abs(($2-mu($1))/$2*100)) title ""

#-----------------------------------------------------------------
set xr [500:*];rep
set xr [*:*];rep
set nologscale

